/*jslint bitwise: true, continue: true, es5: true, newcap: true, nomen: true, regexp: true, sloppy: false,
unparam: true, todo: true, white: true, indent: 4, maxerr: 50, maxlen: 120 */
/*jshint boss: true, curly: true, eqeqeq: true, eqnull: true, es5: true, evil: true, forin: true, laxbreak: true,
loopfunc: true, noarg: true, noempty: true, strict: true, nonew: true, undef: true */
/*global JSON, Vector3D, clock, galaxyNumber, log, missionVariables, player, system, worldScripts */

/* BGS-XMapping
 *
 * Copyright (C) 2010-2014, License: CC BY-NC-SA 4.0
 *
 * This work is licensed under the Creative Commons License
 * Attribution-Noncommercial-Share Alike 4.0 International (CC BY-NC-SA 4.0)
 *
 * To view a copy of this license, visit
 * http://creativecommons.org/licenses/by-nc-sa/4.0/ or send an email
 * to info@creativecommons.org
 *
 * World script to setup BGS-XMapping.
 */

(function () {
    "use strict";

    this.author = "Pagroove, PhantorGorth, Svengali and Tricky";
    this.copyright = "(C) 2010-2014, License: CC BY-NC-SA 4.0";
    this.description = "Advanced mapping.";
    this.license = "CC BY-NC-SA 4.0";
    this.name = "BGS-XMapping";
    this.version = "1.10.1";

    /* World script event handlers. */

    /**
     * We only need to do this once.
     * This will get redefined after a new game or loading of a new Commander.
     */
    this.startUp = function () {
        var ccf = worldScripts.Cabal_Common_Functions,
        snoopersCheck = ["snoopers", null];

        delete this.startUp; // as per PhantorGorth approach

        if (!ccf || ccf.Cabal_Common === 'undefined') {
            this.killSelf(" -> Cabal_Common_Library is missing");

            return;
        }

        this.helper = new ccf.Cabal_Common();

        if (this.helper.internalVersion < 15) {
            this.killSelf(" -> Cabal_Common_Library is too old");

            return;
        }

        this.$snoopersInstalled = true;

        if (!this.helper.oxpVersionTest(this.name, snoopersCheck)) {
            this.$snoopersInstalled = false;
        }

        if (this.$snoopersInstalled) {
            // Set minimum version for Snoopers.
            snoopersCheck[1] = "2.5";

            if (!this.helper.oxpVersionTest(this.name, snoopersCheck)) {
                this.killSelf(" -> Need Snoopers 2.5 or greater");

                return;
            }
        }

        if (worldScripts["BGS-M"].startup) {
            worldScripts["BGS-M"].startup();
        }

        this.minInter = 4; // minimum days - release 4
        this.maxInter = 15; // maximum days - release 15
        this.logging = false;
        this.xmaps = {
            // regions
            areas : [{
                    type : 1,
                    gal : 0,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc1_old_worlds.png",
                    posx : 7.2,
                    posy : 35.6,
                    radi : 6.8
                }, {
                    type : 1,
                    gal : 0,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc1_xexedi_cluster.png",
                    posx : 28,
                    posy : 19.4,
                    radi : 7.2
                }, {
                    type : 1,
                    gal : 0,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc1_iron_stars.png",
                    posx : 32.4,
                    posy : 46,
                    radi : 6.8
                }, {
                    type : 1,
                    gal : 0,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc1_teraed_region.png",
                    posx : 79.9,
                    posy : 14.4,
                    radi : 6.6
                }, {
                    type : 3,
                    gal : 0,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc1_galcenter.png",
                    nvert : 9,
                    ax : [47.928, 52.804, 55.308, 53.62, 48.808, 42.124, 40.248, 40.936, 43.56],
                    ay : [15.989, 18.364, 25.176, 32.180, 35.616, 32.676, 27.736, 21.236, 17.672]
                }, {
                    type : 3,
                    gal : 0,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc1_devils_triangle.png",
                    nvert : 3,
                    ax : [68.008, 70, 74.064],
                    ay : [48.4, 41.48, 45.42]
                }, {
                    type : 3,
                    gal : 0,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc1_pulsar_worlds.png",
                    nvert : 6,
                    ax : [96.84, 98.212, 96.584, 90.72, 83.724, 85.472],
                    ay : [0, 2.94, 6, 7.8, 3.304, 0]
                }, {
                    type : 3,
                    gal : 0,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc1_tortuga_expanse.png",
                    nvert : 10,
                    ax : [96.348, 91.848, 87.356, 87.356, 91.108, 95.676, 98.36, 100.172, 100.796, 100.108],
                    ay : [41.824, 39.448, 32.012, 26.512, 23.264, 25.012, 28.448, 32.008, 35.76, 39.952]
                }, {
                    type : 3,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_citadels_of_chaos.png",
                    nvert : 8,
                    ax : [9.464, 12.112, 17.304, 21.616, 21.992, 19.428, 14.492, 9.552],
                    ay : [21.716, 21.292, 23.168, 27.292, 29.668, 30.412, 28.848, 24.036]
                }, {
                    type : 3,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_equilibrium.png",
                    nvert : 3,
                    ax : [16.172, 23.112, 30.924],
                    ay : [20.48, 12.92, 14.604]
                }, {
                    type : 3,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_fertile_cresent.png",
                    nvert : 7,
                    ax : [5.84, 10.852, 12.728, 11.617, 5.549, 0, 0],
                    ay : [32.996, 35.528, 41.276, 46.637, 50.136, 47.636, 35.704]
                }, {
                    type : 3,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_fiddlers_green.png",
                    nvert : 7,
                    ax : [77.224, 77.224, 81.976, 86.164, 88.852, 87.6, 82.784],
                    ay : [51.2, 44.572, 36.572, 33.948, 36.132, 43.948, 51.2]
                }, {
                    type : 3,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_galcenter.png",
                    nvert : 9,
                    ax : [31.64, 33.892, 34.704, 39.456, 40.46, 42.584, 39.96, 35.144, 31.704],
                    ay : [31.74, 30.052, 25.424, 27.428, 30.364, 32.668, 36.8, 36.8, 33.424]
                }, {
                    type : 3,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_kobs_ladder.png",
                    nvert : 9,
                    ax : [42.44, 41.744, 43.932, 49.184, 53.372, 55.056, 53.368, 49.492, 44.744],
                    ay : [31.268, 28.088, 23.34, 19.844, 19.844, 22.528, 27.528, 31.088, 32.152]
                }, {
                    type : 3,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_qucedi_bottleneck.png",
                    nvert : 7,
                    ax : [6.788, 1.292, 0, 3.816, 8.06, 10.872, 10.688],
                    ay : [21.964, 17.524, 4.268, 0, 2, 8.184, 17.872]
                }, {
                    type : 3,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_ramaans_keep.png",
                    nvert : 6,
                    ax : [93.58, 89.572, 90.512, 93.7, 101.824, 102.2],
                    ay : [51.2, 42.516, 38.08, 36.204, 43.2, 51.2]
                }, {
                    type : 3,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_redline_stars.png",
                    nvert : 8,
                    ax : [39.764, 39.012, 42.384, 49.328, 54.016, 54.704, 51.14, 45.264],
                    ay : [16.448, 12.196, 7.696, 6.388, 8.824, 12.572, 17.448, 18.7]
                }, {
                    type : 3,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_teonan_web.png",
                    nvert : 7,
                    ax : [86.212, 86.212, 89.588, 93.464, 100.028, 101.276, 98.028],
                    ay : [0, 4.628, 8.692, 10.504, 9.256, 6.196, 0]
                }, {
                    type : 3,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_zaedvera_pocket.png",
                    nvert : 8,
                    ax : [58.908, 50.656, 47.148, 50.584, 60.212, 68.584, 72.524, 72.524],
                    ay : [51.2, 47.76, 43.7, 41.572, 42.132, 45.132, 47.568, 51.2]
                }, {
                    type : 3,
                    gal : 2,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc3_galcenter.png",
                    nvert : 9,
                    ax : [52.52, 48.048, 49.02, 45.52, 46.396, 48.46, 55.272, 62.148, 58.272],
                    ay : [39.776, 29.836, 27.208, 15.772, 13.392, 14.58, 26.704, 31.328, 35.704]
                }, {
                    type : 3,
                    gal : 2,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc3_inner_reach.png",
                    nvert : 9,
                    ax : [12.32, 19.632, 20.948, 18.388, 16.7, 7.888, 5.699, 4.136, 5.888],
                    ay : [10.9, 8.46, 4.716, 0.562, 0, 0, 1.624, 4.684, 8.624]
                }, {
                    type : 3,
                    gal : 2,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc3_outer_reach.png",
                    nvert : 9,
                    ax : [95.632, 87.64, 83.452, 83.072, 86.888, 93.072, 99.196, 101.388, 101.388],
                    ay : [13.288, 10.536, 5.972, 2.724, 0.848, 1.6, 5.288, 8.912, 11.352]
                }, {
                    type : 3,
                    gal : 2,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc3_prodigal_suns.png",
                    nvert : 6,
                    ax : [23.588, 22.152, 25.4, 30.524, 33.776, 32.34],
                    ay : [0, 1.056, 3.124, 3.124, 1.064, 0]
                }, {
                    type : 3,
                    gal : 2,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc3_runners_leap.png",
                    nvert : 7,
                    ax : [22.8, 33.74, 39.052, 37.484, 25.672, 13.732, 13.98],
                    ay : [38.264, 38.764, 36.644, 33.641, 34.2, 31.14, 35.08]
                }, {
                    type : 1,
                    gal : 2,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc3_sidewinder_expanse.png",
                    posx : 29.2,
                    posy : 17.366,
                    radi : 9.4
                }, {
                    type : 3,
                    gal : 2,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc3_starbridge_cluster.png",
                    con : 1,
                    nvert : 14,
                    ax : [54.864, 75.368, 80.308, 86.868, 92, 91.06, 82.312, 81.252, 78.812, 76.128, 72.568, 68.692,
                        67.692, 57.128],
                    ay : [51.2, 51.2, 49.392, 51.2, 51.2, 49.136, 40.136, 37.136, 36.824, 35.756, 37.828, 38.704,
                        43.264, 44.388]
                }, {
                    type : 3,
                    gal : 2,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc3_yeon_pass.png",
                    nvert : 9,
                    ax : [5.4, 8.524, 11.464, 9.588, 5.4, 2.08, 0, 0, 1.932],
                    ay : [25.8, 27.428, 35.32, 43.884, 46.82, 45.072, 41.512, 30.136, 27.012]
                }, {
                    type : 3,
                    gal : 3,
                    sn : 2,
                    ov : "bgs-i_overlay_lrc4_razors_edge.png",
                    con : 1,
                    nvert : 37,
                    ax : [7.64, 9.64, 10.14, 12.888, 13.452, 16.76, 22.456, 25.332, 26.52, 26.624, 26.876, 26.068,
                        26.068, 28.568, 29.004, 30.132, 30.44, 32.384, 32.012, 36.504, 40.064, 40.064, 44.628, 44.8,
                        44.004, 36.192, 34.064, 33.572, 30.512, 28.764, 24.956, 22.084, 16.324, 14.888, 13.328, 10.824,
                        7.512],
                    ay : [1.496, 1.796, 2.372, 3.808, 6.304, 5.552, 7.792, 6.168, 6.984, 8.848, 9.908, 11.78, 13.9,
                        13.9, 10.836, 9.96, 11.896, 14.02, 15.704, 16.644, 15.264, 14.012, 11.764, 10.2, 9.388, 13.388,
                        11.764, 9.076, 7.048, 3.572, 2.608, 3.732, 2.06, 2.06, 0.752, 0, 0]
                }, {
                    type : 3,
                    gal : 3,
                    sn : 2,
                    ov : "bgs-i_overlay_lrc4_razors_edge.png",
                    con : 1,
                    nvert : 21,
                    ax : [32.012, 33.232, 35.788, 35.348, 39.536, 43.288, 47.179, 49.93, 51.495, 51.12, 55.44, 53.623,
                        53.935, 52.495, 49.307, 47.743, 46.288, 47.1, 44.104, 39.728, 36.504],
                    ay : [15.704, 18.588, 20.216, 22.092, 23.592, 21.464, 25.76, 25.76, 28.001, 31.628, 31.94, 30.44,
                        26.252, 23.94, 22.94, 23.252, 20.536, 18.472, 17.432, 19.096, 16.644]
                }, {
                    type : 3,
                    gal : 3,
                    sn : 2,
                    ov : "bgs-i_overlay_lrc4_razors_edge.png",
                    con : 1,
                    nvert : 10,
                    ax : [51.12, 48.936, 47.124, 44.124, 45.44, 47, 47.748, 49.572, 51.564, 55.4],
                    ay : [31.628, 33.252, 36.38, 38.568, 40.252, 39.064, 40, 38.196, 34.512, 31.94]
                }, {
                    type : 3,
                    gal : 3,
                    sn : 2,
                    ov : "bgs-i_overlay_lrc4_razors_edge.png",
                    con : 1,
                    nvert : 16,
                    ax : [47.748, 50.064, 53.128, 55.128, 56.816, 56.568, 61.568, 64.884, 64.884, 62.384, 59.824,
                        58.764, 56.952, 56.824, 54.572, 49.572],
                    ay : [40, 43.188, 44.688, 44.812, 47.692, 50.004, 51.3, 51.3, 49.196, 49.32, 48.324, 44.576, 43.764,
                        42.136, 42.384, 38.196]
                }, {
                    type : 3,
                    gal : 3,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc4_vuesar_cordon.png",
                    con : 1,
                    nvert : 12,
                    ax : [0, 0.992, 1.748, 1.748, 2.252, 1.752, 2.876, 6.688, 3.696, 2.26, 0.888, 0],
                    ay : [10.56, 11.988, 11.676, 9.992, 9.992, 11.744, 11.992, 6.616, 5.988, 7.112, 5.864, 6.116]
                }, {
                    type : 3,
                    gal : 3,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc4_unified_democratic_star_league.png",
                    nvert : 9,
                    ax : [43.78, 39.964, 36.908, 37.412, 42.164, 46.476, 50.16, 53.352, 53.856],
                    ay : [51.3, 47.76, 40.252, 34.624, 34.248, 36.996, 42.308, 48.184, 51.3]
                }, {
                    type : 3,
                    gal : 3,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc4_anintorian_irruption.png",
                    con : 1,
                    nvert : 17,
                    ax : [16.4, 18.712, 22.212, 24.464, 26.588, 27.208, 25.46, 26.52, 26.144, 24.208, 22.52, 19.708,
                        19.584, 17.268, 16.768, 15.264, 14.14],
                    ay : [45.7, 45.788, 45.1, 46.348, 45.972, 47.404, 48.592, 49.78, 51.3, 51.3, 48.136, 49.264, 50.704,
                        50.704, 49.52, 49.776, 46.584]
                }, {
                    type : 3,
                    gal : 3,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc4_ririla_influx.png",
                    con : 1,
                    nvert : 7,
                    ax : [93.88, 95.756, 97.504, 99.816, 101.384, 102.5, 102.5],
                    ay : [0, 2.14, 1.388, 3.136, 2.448, 4.7, 0]
                }, {
                    type : 3,
                    gal : 3,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc4_parallel_accord.png",
                    con : 1,
                    nvert : 35,
                    ax : [79.02, 81.956, 83.52, 85.02, 87.08, 85.64, 87.204, 88.892, 91.52, 94.96, 94.204, 95.324, 96.7,
                        99.008, 100.572, 102.4, 102.4, 100.152, 98.652, 98.088, 97.84, 95.592, 92.716, 91.652, 90.46,
                        87.584, 85.96, 80.96, 79.832, 81.332, 80.396, 77.768, 77.024, 77.588, 77.028],
                    ay : [16.896, 13.02, 12.772, 13.9, 12.52, 9.704, 6.584, 7.016, 5.328, 6.704, 10.332, 11.456, 11.456,
                        13.016, 15.02, 15.02, 3.248, 3.248, 5, 4.6, 2.724, 0, 0, 0.752, 0, 0, 2.564, 1.316, 3.004,
                        7.128, 9.196, 9.196, 11.128, 13.38, 15.82]
                }, {
                    type : 3,
                    gal : 3,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc4_galcenter.png",
                    con : 1,
                    nvert : 23,
                    ax : [64.508, 67.32, 67.696, 70.26, 74.196, 75.944, 71.944, 70.632, 70.632, 68.607, 65.73, 61.108,
                        59.672, 54.236, 54.608, 59.672, 61.86, 59.552, 59.3, 60.544, 60.164, 62.348, 63.343],
                    ay : [30.368, 30.368, 26.372, 22.428, 24.364, 22.052, 19.864, 17.86, 10.356, 9.953, 14.017, 12.9,
                        11.464, 13.964, 16.464, 14.648, 17.648, 19.896, 22.396, 25.896, 27.584, 28.708, 27.332]
                }, {
                    type : 3,
                    gal : 3,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc4_foundrys_reach.png",
                    con : 1,
                    nvert : 42,
                    ax : [28.752, 30.436, 30.12, 31.56, 33.12, 34.184, 36.872, 38.688, 41.372, 37.808, 36.932, 35.744,
                        33.308, 31.24, 29.616, 30.216, 28.74, 27.116, 26.116, 26.932, 29.996, 31.436, 33.684, 33.684,
                        31.432, 29.244, 27.368, 25.684, 24.372, 22.936, 20.872, 19.748, 20.872, 21.872, 23.748, 25.504,
                        26.064, 27.248, 27.248, 27.688, 26.128, 27.748],
                    ay : [43.716, 42.524, 38.584, 36.208, 35.644, 34.272, 33.712, 31.528, 29.712, 25.088, 22.896,
                        22.896, 23.034, 21.524, 21.744, 24.088, 24.46, 23.46, 24.272, 26.644, 26.896, 26.52, 27.02,
                        28.896, 30.956, 31.208, 30.52, 30.832, 30.268, 31.144, 30.896, 33.088, 34.092, 34.092, 35.028,
                        33.404, 34.344, 34.344, 36.156, 37.904, 41.032, 43.848]
                }, {
                    type : 3,
                    gal : 3,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc4_lower_insurgency.png",
                    con : 1,
                    nvert : 51,
                    ax : [75.704, 80.392, 82.644, 89.892, 91.076, 91.7, 93.948, 95.824, 97.388, 97.636, 98.638, 99.32,
                        100.82, 101.136, 99.008, 98.32, 100.004, 98.752, 99.74, 98.444, 98.88, 98.068, 97.316, 95.756,
                        94.192, 92.572, 92.572, 95.324, 96.696, 94.82, 94.82, 96.944, 94.944, 94.944, 96.568, 96.072,
                        96.324, 95.452, 92.764, 92.14, 91.136, 88.512, 88.2, 89.012, 86.072, 81.828, 80.58, 78.64,
                        78.14, 76.644, 75.52],
                    ay : [47.316, 50.444, 49.016, 49.016, 47.696, 49.072, 49.072, 48.132, 48.82, 50.94, 50.94, 50.068,
                        49.88, 48.688, 47.376, 45.628, 39.688, 38.688, 37.94, 36.192, 34.124, 30.624, 30.624, 31.308,
                        30.308, 30.684, 32.996, 33.248, 34.556, 36.556, 37.74, 37.928, 38.364, 39.548, 40.548, 41.8,
                        43.116, 43.488, 43.112, 44.86, 43.356, 44.48, 45.424, 46.172, 46.98, 46.98, 47.356, 45.856,
                        44.412, 44.412, 47.284]
                }, {
                    type : 3,
                    gal : 4,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc5_gate_of_damocles.png",
                    nvert : 16,
                    ax : [11.108, 16.044, 20.544, 26.976, 30.352, 32.916, 33.356, 32.792, 30.164, 26.476, 21.412,
                        17.908, 13.968, 11.344, 10.656, 10.656],
                    ay : [16.888, 18.512, 18.016, 14.952, 11.956, 7.832, 4.956, 2.644, 1.264, 1.264, 2.328, 3.828,
                        7.2, 10.764, 13.64, 15.7]
                }, {
                    type : 3,
                    gal : 4,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc5_siege_worlds.png",
                    nvert : 12,
                    ax : [35.556, 39.616, 42.424, 43.984, 43.3, 40.924, 36.108, 32.48, 29.48, 27.728, 28.28, 31.156],
                    ay : [39.112, 38.488, 36.928, 33.484, 30.548, 28.612, 27.552, 27.928, 29.424, 33.364, 35.864, 38.3]
                }, {
                    type : 3,
                    gal : 4,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc5_tetitri_conclave.png",
                    nvert : 8,
                    ax : [7.772, 8.336, 7.464, 4.528, 1.152, 0, 0, 1.936],
                    ay : [51.3, 48.264, 42.768, 37.144, 35.956, 36.204, 48.016, 51.3]
                }, {
                    type : 3,
                    gal : 4,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc5_galcenter.png",
                    nvert : 12,
                    ax : [54.06, 54.872, 57.308, 62.308, 66.624, 69.184, 69.684, 69.184, 67.12, 62.12, 58.12, 55.432],
                    ay : [34.96, 39.272, 43.96, 45.96, 43.892, 39.204, 34.768, 29.64, 25.08, 22.64, 24.204, 27.704]
                }, {
                    type : 3,
                    gal : 4,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc5_galcon_bombard.png",
                    nvert : 12,
                    ax : [82.776, 79.78, 78.352, 77.168, 76.644, 77.268, 79.696, 82.948, 84.948, 86.824, 87.072,
                        86.136],
                    ay : [13.464, 12.712, 11.464, 8.84, 5.684, 2.624, 0, 0, 1.312, 4.876, 8.504, 11.38]
                }, {
                    type : 3,
                    gal : 4,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc5_steel_halo.png",
                    nvert : 10,
                    ax : [98.4, 95.216, 93.032, 92.224, 92.54, 94.1, 98.536, 101.788, 102.4, 102.4],
                    ay : [16.576, 15.64, 13.2, 9.948, 6.26, 3.696, 1.88, 2.88, 3.38, 15.192]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc6_galcenter.png",
                    con : 1,
                    nvert : 33,
                    ax : [51.1, 52.852, 54.352, 56.536, 60.036, 62.6, 64.972, 67.788, 69.6, 70.16, 67.724, 67.724,
                        66.036, 66.848, 66.848, 68.66, 69.472, 64.848, 64.412, 62.348, 60.532, 59.72, 57.22, 56.728,
                        54.604, 52.916, 50.366, 49.98, 51.732, 50.484, 50.484, 49.676, 50.492],
                    ay : [39.452, 39.452, 35.08, 34.208, 34.46, 33.96, 35.268, 38.016, 38.204, 36.388, 33.512, 32.264,
                        29.824, 28.824, 28.136, 28.136, 26.636, 22.636, 21.512, 20.072, 20.072, 18.76, 18.568, 18.488,
                        20.488, 20.052, 21.992, 27.116, 29.056, 30.932, 32.116, 34.308, 38.868]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc6_raonbe_cluster.png",
                    nvert : 10,
                    ax : [43.788, 40.348, 37.972, 37.972, 39.536, 43.536, 47.912, 49.66, 48.908, 46.344],
                    ay : [41.312, 42, 44.436, 47.312, 49.624, 50.764, 49.704, 46.704, 43.456, 41.896]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc6_rabian_spur.png",
                    nvert : 11,
                    ax : [40.524, 38.092, 37.652, 39.092, 44.528, 54.4, 61.212, 66.716, 69.528, 69.404, 63.84],
                    ay : [0, 1.064, 2.94, 4.752, 6.568, 7.944, 7.632, 6.38, 4.88, 2.444, 0]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc6_iron_alliance.png",
                    con : 1,
                    nvert : 23,
                    ax : [81.672, 81.672, 84.228, 85.168, 86.044, 90.916, 92.288, 93.412, 94.412, 96.288, 97.6, 99.352,
                        101.352, 100.6, 101.164, 99.788, 96.536, 93.788, 89.852, 86.916, 85.664, 83.724, 81.664],
                    ay : [8.2, 9.388, 10.516, 13.012, 13.508, 14.444, 15.816, 16.096, 16.068, 14.632, 13.948, 13.948,
                        12.072, 7.508, 4.196, 3.82, 4.008, 2.632, 3.504, 2.94, 3.44, 6.564, 7.38]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc6_isaanus_syndicate.png",
                    nvert : 14,
                    ax : [92.4, 95.552, 97.68, 99.992, 101.864, 102.4, 102.4, 100.712, 98.272, 95.396, 94.272, 93.772,
                        91.836, 91.836],
                    ay : [41.7, 41.324, 43.26, 48.008, 48.064, 46.252, 30.816, 30.816, 33.188, 33.5, 34.5, 36.252,
                        39.124, 41.436]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 17,
                    ov : "bgs-i_overlay_lrc6_centreward_industrial_sector.png",
                    nvert : 18,
                    ax : [9.796, 10.484, 12.296, 13.98, 15.916, 16.288, 19.664, 22.036, 21.976, 22.852, 23.104, 13.728,
                        14.352, 13.984, 14.236, 11.984, 11.296, 9.86],
                    ay : [38.652, 39.84, 39.704, 41.464, 41.4, 38.96, 37.7, 35.952, 33.952, 32.956, 31.02, 31.02, 32.08,
                        33.832, 34.516, 35.764, 36.888, 37.444]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 17,
                    ov : "bgs-i_overlay_lrc6_centreward_industrial_sector.png",
                    con : 1,
                    nvert : 20,
                    ax : [23.196, 26.944, 29.568, 31.26, 30.884, 28.32, 28.32, 30.448, 31.636, 31.32, 31.696, 28.948,
                        14.572, 13.132, 10.068, 8.256, 8.82, 11.444, 12.192, 14.376],
                    ay : [31.8, 31.8, 32.548, 31.424, 30.172, 28.86, 27.732, 28.536, 27.856, 25.984, 24.112, 23.736,
                        23.736, 26.612, 26.052, 27.052, 28.864, 28.612, 30.108, 31.604]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 17,
                    ov : "bgs-i_overlay_lrc6_centreward_industrial_sector.png",
                    con : 1,
                    nvert : 15,
                    ax : [29.444, 28.628, 29.688, 29.316, 27.38, 29.004, 30.128, 20.196, 16.948, 16.324, 16.948, 16.448,
                        14.76, 14.76, 14.012],
                    ay : [24.08, 22.388, 21.444, 19.52, 17.144, 16.572, 15.012, 15.264, 16.392, 17.704, 20.08, 20.892,
                        21.328, 23.388, 24.948]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 17,
                    ov : "bgs-i_overlay_lrc6_centreward_industrial_sector.png",
                    con : 1,
                    nvert : 43,
                    ax : [27.644, 29.412, 30.1, 31.352, 35.852, 34.292, 36.172, 37.236, 39.484, 39.984, 39.048, 39.984,
                        38.04, 36.852, 35.104, 34.172, 35.86, 36.296, 35.112, 33.864, 31.924, 31.364, 31.616, 30.928,
                        30.928, 29.552, 26.988, 25.612, 23.676, 22.68, 20.304, 18.744, 17.868, 16.116, 15.864, 16.296,
                        15.42, 15.608, 21.104, 20.356, 20.356, 17.604, 16.352],
                    ay : [16.8, 16.3, 14.804, 15.116, 14.432, 14.68, 13.676, 15.736, 15.36, 14.172, 11.492, 9.432,
                        8.432, 8.932, 10.368, 9.056, 7.868, 6.304, 5.432, 4.308, 4.56, 6.312, 7.628, 9.376, 10.564,
                        11.752, 11.752, 10.128, 10.564, 8.44, 8.128, 6.064, 3.94, 3.94, 5.628, 6.628, 7.692, 9.444,
                        12.384, 13.88, 15.004, 16.004, 17.192]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc6_lost_worlds.png",
                    nvert : 11,
                    ax : [90.076, 90.888, 91.2, 89.952, 87.076, 84.328, 82.576, 81.576, 82.2, 84.08, 86.204],
                    ay : [51.2, 49.892, 46.704, 41.016, 35.828, 34.644, 35.768, 39.456, 44.144, 48.896, 51.2]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 18,
                    ov : "bgs-i_overlay_lrc6_rimward_industrial_sector.png",
                    con : 1,
                    nvert : 25,
                    ax : [79.428, 80.112, 81.984, 85.172, 86.92, 88.044, 89.732, 91.668, 92.98, 94.4, 94.044, 92.92,
                        91.164, 89.168, 87.92, 87.232, 85.984, 85.424, 83.988, 83.612, 81.924, 80.864, 79.24, 77.864,
                        75.804],
                    ay : [30.44, 30.252, 29.128, 28.868, 29.056, 28.248, 26.188, 25.5, 24.436, 23.872, 21.688, 21.688,
                        22.376, 20.94, 20.94, 19.504, 18.38, 16.504, 15.628, 14.188, 13.316, 11.316, 10.628, 11.316,
                        13.128]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 18,
                    ov : "bgs-i_overlay_lrc6_rimward_industrial_sector.png",
                    con : 1,
                    nvert : 17,
                    ax : [75.8, 73.676, 71.492, 68.992, 66.8, 66.616, 65.432, 65.056, 65.62, 68.428, 69.236, 70.364,
                        73.36, 74.364, 76.992, 77.868, 79.428],
                    ay : [13.128, 12.692, 13.384, 11.448, 12.26, 13.948, 15.008, 18.316, 19.252, 21.004, 22.628, 23.068,
                        24.756, 26.256, 27.252, 29.252, 30.44]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc6_anenbian_confederacy.png",
                    con : 1,
                    nvert : 26,
                    ax : [63.872, 68.748, 70.936, 72.56, 73.748, 75.436, 75.748, 78.624, 79.752, 80.064, 78.752, 75.376,
                        74.44, 73, 71.312, 68.876, 66.628, 65, 63.5, 62.312, 61, 60.436, 60.748, 60.124, 59.94, 60.316],
                    ay : [51.2, 48.948, 51.012, 50.824, 51.2, 51.2, 48.512, 45.26, 44.572, 42.136, 41.76, 42.824,
                        42.076, 38.26, 37.448, 39.196, 39.948, 40.26, 39.512, 38.576, 40.068, 42.192, 44.944, 46.944,
                        49.196, 51.2]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc6_anener_commonwealth.png",
                    con : 1,
                    nvert : 23,
                    ax : [10.348, 10.1, 10.6, 14.476, 16.036, 18.412, 19.348, 20.968, 22.344, 23.408, 25.596, 27.408,
                        29.04, 30.6, 30.1, 27.788, 27.788, 22.664, 21.784, 19.472, 16.036, 15.724, 14.656],
                    ay : [0, 1.248, 2.248, 4.932, 3.552, 4.176, 6.736, 6.804, 6.744, 9.056, 9.056, 10.928, 11.116,
                        10.116, 8.112, 6.8, 3.548, 2.424, 0.36, 0, 0, 0.5, 0]
                }, {
                    type : 3,
                    gal : 5,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc6_jaws_of_cerberus.png",
                    con : 1,
                    nvert : 20,
                    ax : [97.396, 99.14, 100.328, 101.952, 102.4, 102.4, 102.084, 101.648, 101.588, 100.092, 99.22,
                        98.844, 96.912, 94.352, 94.724, 96.352, 97.352, 97.352, 95.852, 96.1],
                    ay : [33.156, 32.28, 30.720, 30.156, 29.656, 25.092, 22.968, 22.22, 19.908, 18.284, 16.344, 14.528,
                        14.528, 22.78, 24.532, 24.532, 26.156, 28.532, 31.032, 32.6]
                }, {
                    type : 3,
                    gal : 6,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc7_galcenter.png",
                    con : 1,
                    nvert : 35,
                    ax : [88.8, 90.608, 92.356, 92.356, 94.044, 94.044, 96.232, 95.984, 95.98, 94.54, 93.664, 92.04,
                        91.416, 89.168, 87.916, 86.984, 85.612, 84.74, 82.74, 81.6, 78.912, 74.472, 72.724, 73.164,
                        74.788, 75.6, 78.536, 79.596, 79.284, 80.384, 81.788, 83.6, 85.352, 86.852, 87.664],
                    ay : [39.5, 38, 36.812, 35.56, 34.188, 32.312, 31.132, 29.132, 26.82, 25.76, 24.076, 24.016, 23.016,
                        23.016, 21.952, 21.072, 21.572, 23.76, 23.948, 25.844, 26.344, 31.28, 32.468, 34.404, 34.404,
                        33.28, 31.088, 32.46, 33.896, 36.524, 37.148, 35.836, 35.836, 37.212, 39.208]
                }, {
                    type : 3,
                    gal : 6,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc7_five_points_trade_barrier.png",
                    con : 1,
                    nvert : 12,
                    ax : [1.58, 3.704, 6.712, 8.528, 9.216, 6.528, 3.836, 0.836, 0, 0, 0.312, 0.872],
                    ay : [32.996, 34.436, 34.872, 36.624, 39.932, 40.744, 39.436, 39.872, 39.06, 36.184, 33.432, 33.12]
                }, {
                    type : 3,
                    gal : 6,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc7_isare_pact.png",
                    con : 1,
                    nvert : 17,
                    ax : [67.788, 69.412, 69.1, 67.54, 68.04, 67.48, 65.668, 61.792, 59.916, 58.544, 58.356, 59.104,
                        59.916, 60.916, 62.352, 64.728, 66.788],
                    ay : [13.216, 11.964, 10.34, 8.968, 6.656, 5.344, 5.344, 9.156, 8.652, 9.528, 11.216, 11.784,
                        11.656, 13.096, 13.096, 12.224, 12.912]
                }, {
                    type : 3,
                    gal : 6,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc7_galcop_central_intelligence_sector.png",
                    nvert : 13,
                    ax : [38.444, 40.632, 42.008, 41.632, 40.068, 38.252, 35.876, 33.316, 32.004, 31.756, 32.504,
                        34.316, 36.316],
                    ay : [25.1, 24.412, 21.852, 17.604, 14.604, 12.852, 11.852, 12.476, 15.164, 18.228, 20.792, 23.168,
                        24.664]
                }, {
                    type : 3,
                    gal : 6,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc7_rubicon_crossroad.png",
                    nvert : 8,
                    ax : [0, 0, 10.568, 11.132, 10.32, 7.568, 4.068, 1.068],
                    ay : [46.36, 51.2, 51.2, 48.824, 46.388, 45.324, 44.7, 45.768]
                }, {
                    type : 3,
                    gal : 6,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc7_kleptocratic_swathe.png",
                    con : 1,
                    nvert : 26,
                    ax : [28.4, 30.4, 31.964, 33.716, 36.216, 37.836, 39.96, 42.9, 46.02, 47.332, 47.02, 45.084, 41.708,
                        39.832, 38.644, 37.456, 36.456, 34.58, 33.144, 31.084, 29.904, 28.968, 28.156, 28.156, 27.344,
                        27.532],
                    ay : [42.3, 41.74, 41.808, 41.56, 42.124, 41.784, 42.436, 42.684, 44.312, 43.624, 41.872, 41.624,
                        39.936, 40.612, 39.736, 37.484, 37.232, 37.424, 36.112, 35.236, 34.364, 34.988, 37.052, 38.428,
                        40.428, 41.804]
                }, {
                    type : 3,
                    gal : 7,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc8_ladle.png",
                    nvert : 11,
                    ax : [99.096, 100.908, 101.656, 100.22, 97.408, 95.22, 93.096, 92.472, 93.22, 95.032, 96.968],
                    ay : [34.672, 33.92, 31.54, 27.98, 25.544, 25.044, 25.856, 28.04, 30.356, 32.792, 34.232]
                }, {
                    type : 3,
                    gal : 7,
                    sn : 19,
                    ov : "bgs-i_overlay_lrc8_crystaline_desolation.png",
                    con : 1,
                    nvert : 42,
                    ax : [21.699, 23.071, 25.007, 25.759, 28.323, 29.511, 30.195, 31.631, 33.631, 33.631, 32.571,
                        30.195, 30.195, 32.323, 34.011, 35.263, 37.455, 38.079, 40.015, 38.763, 39.263, 38.263, 37.203,
                        35.891, 33.575, 31.763, 29.887, 29.139, 29.951, 31.079, 32.019, 31.707, 30.395, 28.083, 26.583,
                        25.331, 23.207, 23.207, 21.959, 22.519, 21.707, 18.703],
                    ay : [17.021, 14.957, 14.645, 13.829, 15.889, 19.761, 20.885, 20.325, 19.885, 19.261, 18.949,
                        16.949, 15.389, 15.765, 17.077, 16.513, 16.513, 16.013, 16.013, 14.453, 12.393, 12.145, 13.209,
                        13.209, 14.329, 13.701, 13.137, 11.889, 11.137, 11.885, 11.573, 10.009, 7.385, 7.509, 5.821,
                        5.821, 9.693, 10.569, 11.197, 13.197, 14.573, 16.197]
                }, {
                    type : 3,
                    gal : 7,
                    sn : 19,
                    ov : "bgs-i_overlay_lrc8_crystaline_desolation.png",
                    con : 1,
                    nvert : 26,
                    ax : [25.357, 25.357, 23.985, 23.485, 21.861, 21.173, 21.297, 20.109, 20.669, 20.293, 21.545,
                        23.417, 22.229, 20.105, 18.413, 17.289, 16.661, 18.225, 19.537, 21.789, 22.413, 24.909, 25.097,
                        24.537, 25.161, 25.973],
                    ay : [29.319, 28.071, 26.507, 24.507, 24.507, 23.131, 21.755, 21.255, 19.315, 17.815, 17.379,
                        14.879, 14.255, 14.567, 17.131, 16.695, 17.567, 22.815, 25.315, 27.627, 30.251, 31.375, 33.251,
                        34.627, 35.751, 37.687]
                }, {
                    type : 3,
                    gal : 7,
                    sn : 19,
                    ov : "bgs-i_overlay_lrc8_crystaline_desolation.png",
                    con : 1,
                    nvert : 28,
                    ax : [24.16, 26.788, 28.908, 28.908, 27.220, 27.156, 27.776, 27.028, 28.78, 32.092, 34.968, 35.156,
                        33.844, 32.836, 31.96, 29.336, 27.084, 25.456, 24.768, 21.648, 22.46, 22.96, 24.896, 25.208,
                        24.392, 24.392, 25.516, 26.076],
                    ay : [38.28, 40.72, 38.596, 36.408, 36.032, 34.66, 34.16, 32.532, 30.844, 30.28, 30.968, 29.22,
                        28.096, 27.096, 28.72, 28.972, 28.408, 29.096, 28.156, 27.032, 29.404, 30.592, 31.028, 33.468,
                        34.532, 35.404, 35.652, 37.716]
                }, {
                    type : 3,
                    gal : 7,
                    sn : 19,
                    ov : "bgs-i_overlay_lrc8_crystaline_desolation.png",
                    con : 1,
                    nvert : 54,
                    ax : [26.032, 26.032, 24.344, 23.22, 22.096, 21.16, 18.724, 18.54, 18.356, 19.104, 19.668, 19.484,
                        19.924, 21.864, 21.864, 23.112, 23.428, 25.68, 26.244, 24.364, 27.364, 28.552, 28.248, 28.936,
                        30.124, 30.5, 32.124, 33.752, 37.316, 40.94, 42.692, 42.692, 41.756, 42.196, 44.196, 45.196,
                        45.824, 47.076, 47.452, 47.02, 47.772, 46.896, 46.896, 44.956, 43.268, 41.516, 40.828, 39.324,
                        37.388, 35.576, 33.76, 31.26, 28.828, 28.824],
                    ay : [36.340, 38.276, 38.464, 37.776, 38.088, 38.088, 39.652, 40.652, 41.716, 43.348, 43.596,
                        44.476, 46.604, 46.98, 48.668, 49.044, 51.2, 51.2, 49.264, 46.704, 45.52, 43.584, 42.02, 41.644,
                        42.084, 41.016, 41.328, 39.140, 40.14, 41.572, 41.572, 43.948, 45.324, 46.388, 45.388, 47.576,
                        47.952, 47.704, 45.328, 43.952, 43.016, 41.956, 41.024, 41.152, 39.968, 40.216, 38.844, 39.28,
                        37.9, 37.772, 37.396, 38.892, 38.58, 36.396]
                }, {
                    type : 3,
                    gal : 7,
                    sn : 19,
                    ov : "bgs-i_overlay_lrc8_crystaline_desolation.png",
                    con : 1,
                    nvert : 57,
                    ax : [44.304, 45.240, 45.300, 47.300, 47.988, 47.860, 50.796, 51.296, 50.108, 49.860, 50.800,
                        54.428, 54.244, 55.432, 58.112, 59.984, 60.920, 61.796, 63.736, 64.860, 66.548, 69.048, 70.300,
                        73.240, 75.052, 76.180, 78.560, 79.744, 80.932, 84.372, 85.184, 84.248, 82.312, 80.000, 78.068,
                        75.128, 74.316, 72.188, 71.056, 69.804, 68.740, 65.552, 63.864, 61.928, 60.928, 59.180, 56.992,
                        55.120, 52.556, 51.868, 50.244, 47.496, 46.992, 47.868, 46.928, 46.928, 44.928],
                    ay : [45.196, 46.760, 47.884, 47.576, 48.700, 51.200, 51.200, 50.324, 48.200, 47.200, 46.136,
                        45.260, 44.508, 43.512, 43.512, 43.512, 42.948, 43.760, 44.072, 43.824, 45.948, 46.512, 46.200,
                        46.200, 47.696, 47.444, 48.384, 47.200, 45.016, 44.392, 43.516, 42.200, 42.764, 43.076, 45.700,
                        44.760, 43.824, 43.076, 44.016, 44.016, 44.204, 41.828, 42.080, 40.576, 40.700, 41.196, 41.196,
                        40.884, 41.132, 43.196, 43.508, 45.448, 44.200, 42.896, 42.084, 41.020, 41.144]
                }, {
                    type : 3,
                    gal : 7,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc8_unified_tech_core.png",
                    nvert : 11,
                    ax : [21.132, 20.88, 19.068, 14.192, 10.316, 7.692, 5.068, 5.692, 7.632, 10.696, 14.384],
                    ay : [51.2, 47.012, 42.076, 35.576, 32.636, 32.072, 34.072, 38.944, 43.072, 47.508, 51.2]
                }, {
                    type : 1,
                    gal : 7,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc8_riven_hitachi_senate.png",
                    posx : 47.136,
                    posy : 44.324,
                    radi : 10.3
                }, {
                    type : 3,
                    gal : 7,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc8_beggars_loop.png",
                    con : 1,
                    nvert : 28,
                    ax : [67.616, 70.3, 71.736, 73.676, 75.68, 77.432, 78.308, 79.12, 80.308, 81.18, 82.804, 82.188,
                        81.248, 79.872, 78.56, 75.62, 67.56, 65.812, 62.876, 62.876, 64.06, 65.936, 67.436, 68.188,
                        67.5, 67.504, 67.136, 67.324],
                    ay : [13.916, 13.668, 13.356, 13.668, 12.732, 10.484, 10.796, 11.044, 11.044, 9.168, 8.484, 6.86,
                        1.796, 1.172, 0.356, 0, 0, 0.5, 6.06, 7.624, 7.312, 5.748, 5.064, 6, 7.376, 8.88, 9.504, 11.944]
                }, {
                    type : 3,
                    gal : 7,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc8_far_arm_star_cluster.png",
                    con : 1,
                    nvert : 20,
                    ax : [98.699, 99.008, 97.508, 96.072, 97.444, 102.4, 102.4, 98.592, 95.968, 93.279, 90.903, 89.78,
                        88.528, 89.716, 89.716, 90.9, 90.588, 91.9, 91.272, 92.584],
                    ay : [51.2, 49.392, 45.636, 43.136, 41.948, 41.76, 39.512, 40.32, 39.692, 39.688, 34.564, 33.752,
                        35.564, 38.064, 40.128, 41.444, 44.816, 47.376, 49.624, 51.2]
                }, {
                    type : 3,
                    gal : 7,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc8_galcenter.png",
                    con : 1,
                    nvert : 42,
                    ax : [62.572, 63.448, 64.764, 65.02, 64.456, 65.332, 65.332, 63.96, 63.464, 61.464, 59.78, 60.092,
                        58.404, 56.964, 56.28, 55.22, 51.596, 48.848, 46.852, 46.224, 43.912, 43.476, 41.848, 41.036,
                        39.848, 38.476, 39.348, 41.16, 45.096, 46.408, 48.032, 50.224, 50.912, 53.788, 55.036, 56.412,
                        57.724, 58.284, 60.032, 60.032, 59.908, 61.22],
                    ay : [33.72, 30.972, 27.912, 26.852, 25.976, 24.6, 21.72, 20.968, 19.776, 17.96, 17.96, 16.46,
                        15.212, 11.836, 9.152, 8.588, 10.84, 10.84, 12.84, 14.28, 14.78, 16.4, 17.524, 22.088, 21.776,
                        24.028, 25.652, 29.152, 28.652, 28.276, 28.904, 27.968, 26.092, 26.092, 27.28, 27.592, 27.472,
                        28.908, 29.908, 32.284, 33.848, 34.724]
                }
            ],
            // spacelanes, routes
            lanes : [{
                    type : 4,
                    gal : 0,
                    sn : 21,
                    ov : "bgs-i_overlay_lrc1_lane_1.png",
                    pos : [
                        [8, 34.6],
                        [13.2, 37],
                        [17.6, 35.2],
                        [21.2, 32],
                        [18, 27.8],
                        [19.6, 23.8],
                        [22, 20.4],
                        [28.4, 17.6],
                        [27.6, 14.4]
                    ]
                }, {
                    type : 4,
                    gal : 0,
                    sn : 21,
                    ov : "bgs-i_overlay_lrc1_lane_1.png",
                    pos : [
                        [21.2, 32],
                        [20.8, 25.6],
                        [26, 21.6],
                        [28.4, 17.6]
                    ]
                }, {
                    type : 4,
                    gal : 0,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc1_lane_2.png",
                    pos : [
                        [8, 34.6],
                        [13.2, 37],
                        [17.6, 35.2],
                        [21.2, 32],
                        [26.4, 29.2],
                        [32.4, 26.6],
                        [38.4, 26],
                        [42, 26.4],
                        [44.4, 25.4],
                        [48, 22.4]
                    ]
                }, {
                    type : 4,
                    gal : 0,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc1_lane_3.png",
                    pos : [
                        [48, 22.4],
                        [53.2, 24.2],
                        [56.4, 23.2],
                        [58.4, 22.4],
                        [59.6, 20.2],
                        [65.6, 17.8],
                        [71.2, 16.8],
                        [74.4, 14.4],
                        [79.6, 16]
                    ]
                }, {
                    type : 4,
                    gal : 0,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc1_lane_4.png",
                    pos : [
                        [79.59, 16],
                        [79.61, 10],
                        [78, 7.8],
                        [79.6, 2.8],
                        [85.6, 1.4],
                        [90.8, 0]
                    ]
                }, {
                    type : 4,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_erlage_corridor.png",
                    pos : [
                        [38.8, 28.4],
                        [36.4, 31.8],
                        [36.6, 33.6],
                        [38.4, 35],
                        [43.6, 30.2]
                    ]
                }, {
                    type : 4,
                    gal : 1,
                    sn : 3,
                    ov : "bgs-i_overlay_lrc2_lane_1.png",
                    pos : [
                        [20.8, 43.2],
                        [24, 48.4],
                        [26, 46.8],
                        [32, 43],
                        [33.6, 39.4],
                        [36.8, 33.6],
                        [36.4, 31.8],
                        [37.2, 29.4],
                        [37.2, 24.8]
                    ]
                }, {
                    type : 4,
                    gal : 1,
                    sn : 3,
                    ov : "bgs-i_overlay_lrc2_lane_1.png",
                    pos : [
                        [23.6, 43.4],
                        [24, 48.4]
                    ]
                }, {
                    type : 4,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_lane_2.png",
                    pos : [
                        [37.2, 24.8],
                        [39.2, 20],
                        [41.2, 16.2],
                        [44, 12.2],
                        [50.4, 14.6],
                        [55.6, 14.2],
                        [53.2, 10.2],
                        [57.6, 6.6],
                        [64, 7],
                        [64, 6],
                        [64.8, 3.2],
                        [67.6, 0.6],
                        [72, 4.4],
                        [76, 8]
                    ]
                }, {
                    type : 4,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_lane_3.png",
                    pos : [
                        [76, 8],
                        [82.4, 6.4],
                        [87.6, 4.4],
                        [90.4, 6.6],
                        [92, 5.4]
                    ]
                }, {
                    type : 4,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_maorin_pass.png",
                    pos : [
                        [2.8, 14],
                        [5.6, 18.4],
                        [10.4, 22.4],
                        [14.8, 20.6],
                        [18.8, 18.8],
                        [22.4, 14.4],
                        [27.6, 14.6],
                        [32.8, 17],
                        [38.4, 19],
                        [41.2, 16.2]
                    ]
                }, {
                    type : 4,
                    gal : 1,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc2_tomoka_run.png",
                    pos : [
                        [55.6, 14.2],
                        [56, 17.6],
                        [58.4, 20.4],
                        [59.6, 20.8],
                        [63.3, 21.2],
                        [66.8, 18.6],
                        [71.2, 13.2],
                        [76, 8]
                    ]
                }, {
                    type : 4,
                    gal : 2,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc3_broken_circle.png",
                    pos : [
                        [8, 7.8],
                        [6.4, 5.6],
                        [7.6, 1.6],
                        [14, 1.2],
                        [18, 1.6],
                        [16.8, 6]
                    ]
                }, {
                    type : 4,
                    gal : 2,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc3_chancers_ally.png",
                    pos : [
                        [55.2, 30.4],
                        [60.8, 32],
                        [65.6, 28.2],
                        [66, 28.8],
                        [66.4, 33.2],
                        [68.4, 35.8],
                        [70, 41.4]
                    ]
                }, {
                    type : 4,
                    gal : 2,
                    sn : 4,
                    ov : "bgs-i_overlay_lrc3_glasnost_corridor.png",
                    pos : [
                        [14, 41.4],
                        [20.4, 44.2],
                        [20.4, 45.8]
                    ]
                }, {
                    type : 4,
                    gal : 2,
                    sn : 4,
                    ov : "bgs-i_overlay_lrc3_glasnost_corridor.png",
                    pos : [
                        [16, 50],
                        [20.4, 45.8],
                        [22.8, 48.6]
                    ]
                }, {
                    type : 4,
                    gal : 2,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc3_lane_1.png",
                    pos : [
                        [38, 50.6],
                        [42, 46.4],
                        [48.0, 45.4],
                        [51.62, 46.41],
                        [49.2, 41.0],
                        [52.8, 38.4],
                        [52.8, 36.4],
                        [53.2, 34.8],
                        [54.4, 32.6],
                        [55.2, 30.4],
                        [54.8, 29.4],
                        [52, 24],
                        [58, 22.2],
                        [60, 20.2],
                        [59.6, 14],
                        [60.4, 12.8]
                    ]
                }, {
                    type : 4,
                    gal : 2,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc3_lane_2.png",
                    pos : [
                        [52.8, 0],
                        [54.4, 6.2],
                        [57.2, 11.2],
                        [60, 12.4],
                        [60.4, 12.8],
                        [65.6, 10.8],
                        [67.6, 8.2],
                        [73.2, 7.8],
                        [74.4, 3.2]
                    ]
                }, {
                    type : 4,
                    gal : 2,
                    sn : 5,
                    ov : "bgs-i_overlay_lrc3_triskelion_conduit.png",
                    pos : [
                        [76.8, 43.2],
                        [80.8, 43],
                        [79.2, 41],
                        [82.8, 35.6],
                        [85.6, 35.2],
                        [90.4, 36.6],
                        [93.2, 42.8],
                        [98.8, 41.4]
                    ]
                }, {
                    type : 4,
                    gal : 2,
                    sn : 5,
                    ov : "bgs-i_overlay_lrc3_triskelion_conduit.png",
                    pos : [
                        [98, 26.6],
                        [95.2, 29],
                        [94, 30.2],
                        [98, 35.2],
                        [98.8, 41.4],
                        [96, 47.4],
                        [100.8, 50]
                    ]
                }, {
                    type : 4,
                    gal : 3,
                    sn : 6,
                    ov : "bgs-i_overlay_lrc4_sunspan_pass.png",
                    pos : [
                        [1.6, 23.2],
                        [2.4, 26.4],
                        [3.2, 29.8],
                        [7.2, 32],
                        [12, 35.4],
                        [12.3, 36.8],
                        [12.5, 36.8],
                        [11.2, 39.6],
                        [10.8, 42],
                        [16.4, 45.6],
                        [16.4, 46],
                        [18.4, 43.6],
                        [24.4, 45.8],
                        [28.4, 41.6],
                        [32.8, 42.2],
                        [36.4, 37.6],
                        [31.6, 34],
                        [28.8, 35.6],
                        [26.8, 32.2]
                    ]
                }, {
                    type : 4,
                    gal : 3,
                    sn : 6,
                    ov : "bgs-i_overlay_lrc4_sunspan_pass.png",
                    pos : [
                        [2.4, 23.2],
                        [2.4, 26.4],
                        [3.2, 29.8]
                    ]
                }, {
                    type : 4,
                    gal : 3,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc4_supply_line_1.png",
                    pos : [
                        [52, 49.6],
                        [48.4, 49.4],
                        [46.8, 46.2],
                        [44.4, 43.4],
                        [44, 43],
                        [42, 40.6],
                        [39.6, 37.8],
                        [40.8, 35.6],
                        [42.8, 29.2],
                        [39.2, 29],
                        [40.4, 25.4],
                        [36, 24.2],
                        [30, 23.4],
                        [30.8, 17.589],
                        [30.9, 17.6],
                        [30.8, 17.6],
                        [27.6, 17],
                        [30.8, 14.4],
                        [34, 9.4],
                        [32, 4.6],
                        [33.6, 1.6]
                    ]
                }, {
                    type : 4,
                    gal : 3,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc4_sanctuarys_way.png",
                    pos : [
                        [45.6, 10.6],
                        [48.8, 13.4],
                        [55.2, 14.8],
                        [59.6, 12.8],
                        [64.8, 16.2],
                        [68, 15.8],
                        [69.6, 20.2],
                        [75.2, 19],
                        [76, 20.2],
                        [81.2, 22],
                        [86.4, 18.4],
                        [89.6, 17],
                        [96.4, 18.8],
                        [101.6, 23]
                    ]
                }, {
                    type : 4,
                    gal : 3,
                    sn : 7,
                    ov : "bgs-i_overlay_lrc4_lane_1.png",
                    pos : [
                        [61.6, 46.6],
                        [66, 41],
                        [64, 39.8],
                        [66.8, 37],
                        [60.8, 34.8],
                        [65.22, 32],
                        [61.2, 31.6],
                        [61.63, 27.2],
                        [60.4, 22],
                        [63.6, 17.6],
                        [68, 15.8],
                        [68.8, 13.8],
                        [69.2, 11.2],
                        [70, 6.2]
                    ]
                }, {
                    type : 4,
                    gal : 3,
                    sn : 7,
                    ov : "bgs-i_overlay_lrc4_lane_1.png",
                    pos : [
                        [71.6, 41.6],
                        [66, 41]
                    ]
                }, {
                    type : 4,
                    gal : 3,
                    sn : 7,
                    ov : "bgs-i_overlay_lrc4_lane_1.png",
                    pos : [
                        [59.6, 4.8],
                        [65.2, 9.4],
                        [69.2, 11.2]
                    ]
                }, {
                    type : 4,
                    gal : 3,
                    sn : 7,
                    ov : "bgs-i_overlay_lrc4_lane_1.png",
                    pos : [
                        [67.2, 7.8],
                        [69.2, 11.2]
                    ]
                }, {
                    type : 4,
                    gal : 3,
                    sn : 8,
                    ov : "bgs-i_overlay_lrc4_supply_line_2.png",
                    pos : [
                        [77.2, 43.4],
                        [79.6, 37.8],
                        [80.8, 36.4],
                        [81.6, 32.6],
                        [84, 27.4],
                        [81.2, 22],
                        [86.4, 18.4],
                        [89.6, 17],
                        [86.601, 11],
                        [88.8, 5],
                        [85.6, 4.2],
                        [90, 3.2],
                        [92.8, 2.4],
                        [96.8, 6.4],
                        [100.8, 4.6],
                        [101.6, 10],
                        [100.8, 12.6]
                    ]
                }, {
                    type : 4,
                    gal : 3,
                    sn : 8,
                    ov : "bgs-i_overlay_lrc4_supply_line_2.png",
                    pos : [
                        [79.6, 37.8],
                        [81.6, 37.2],
                        [87.2, 41],
                        [91.2, 37.4],
                        [94.8, 34.8]
                    ]
                }, {
                    type : 4,
                    gal : 3,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc4_esonlear_cakewalk.png",
                    pos : [
                        [87.2, 41],
                        [88.4, 43.4],
                        [92.8, 47.4],
                        [96.8, 46.6],
                        [99.6, 50.6]
                    ]
                }, {
                    type : 4,
                    gal : 4,
                    sn : 9,
                    ov : "bgs-i_overlay_lrc5_serenic_arc.png",
                    pos : [
                        [4, 11.2],
                        [6.4, 14.2],
                        [11.6, 18],
                        [14, 20.8],
                        [15.2, 22.8],
                        [18.4, 24.8],
                        [21.6, 21.4],
                        [22.8, 20.2],
                        [28.4, 22.6]
                    ]
                }, {
                    type : 4,
                    gal : 4,
                    sn : 9,
                    ov : "bgs-i_overlay_lrc5_serenic_arc.png",
                    pos : [
                        [18, 42.8],
                        [20.4, 40.4],
                        [21.2, 36],
                        [24.4, 32.4],
                        [24.8, 28.4],
                        [28, 23.4],
                        [28.4, 22.6],
                        [28.8, 19],
                        [30.8, 13.8],
                        [31.2, 11.2],
                        [37.2, 8.4],
                        [38.8, 7.4]
                    ]
                }, {
                    type : 4,
                    gal : 4,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc5_lesser_wheel.png",
                    pos : [
                        [44.4, 30.8],
                        [44, 25],
                        [41.2, 25.6],
                        [42, 18.6],
                        [44, 13],
                        [45.6, 6.2],
                        [44.4, 5.8],
                        [40.8, 4.8],
                        [40, 5.8],
                        [38.8, 7.4],
                        [37.2, 8.4],
                        [37.2, 13.2],
                        [41.2, 14],
                        [44, 13]
                    ]
                }, {
                    type : 4,
                    gal : 4,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc5_lane_1.png",
                    pos : [
                        [71.21, 44.405],
                        [69.2, 46.6],
                        [65.2, 49.2],
                        [63.2, 50.2],
                        [61.2, 44.2],
                        [60.8, 41.8],
                        [60, 34.6],
                        [56, 35.4],
                        [56, 35],
                        [59.2, 32.2],
                        [62.4, 29.6],
                        [60, 34],
                        [65.2, 31.2],
                        [66.8, 35.6],
                        [67.6, 32.8],
                        [73.2, 29.4],
                        [74.8, 26.4]
                    ]
                }, {
                    type : 4,
                    gal : 4,
                    sn : 10,
                    ov : "bgs-i_overlay_lrc5_lane_2.png",
                    pos : [
                        [6.4, 50.4],
                        [4.8, 48],
                        [5.2, 44.2],
                        [1.6, 39],
                        [6.8, 34.4],
                        [7.6, 34.8],
                        [12.4, 37],
                        [14.4, 40.8],
                        [18, 42.8],
                        [22.4, 48],
                        [26.4, 47.8],
                        [32, 44.8],
                        [34, 44.2],
                        [34.4, 40.2]
                    ]
                }, {
                    type : 4,
                    gal : 4,
                    sn : 10,
                    ov : "bgs-i_overlay_lrc5_lane_2.png",
                    pos : [
                        [12.4, 37],
                        [13.6, 36.2],
                        [16, 32.2],
                        [21.2, 36],
                        [26.8, 36.8],
                        [29.2, 39.6],
                        [29.2, 40.6],
                        [28.8, 44.2],
                        [32, 44.8]
                    ]
                }, {
                    type : 4,
                    gal : 4,
                    sn : 10,
                    ov : "bgs-i_overlay_lrc5_lane_2.png",
                    pos : [
                        [34.4, 40.2],
                        [38, 42.8],
                        [40.4, 48],
                        [44, 49],
                        [49.2, 46.4],
                        [48.8, 46],
                        [49.2, 40.4],
                        [43.6, 39.6],
                        [39.6, 38.8],
                        [38, 42.8]
                    ]
                }, {
                    type : 4,
                    gal : 4,
                    sn : 11,
                    ov : "bgs-i_overlay_lrc5_zalexe_loop.png",
                    pos : [
                        [101.6, 31.6],
                        [97.2, 29],
                        [95.6, 31.2],
                        [94, 32.2],
                        [89.2, 33],
                        [84, 31.2],
                        [88.4, 25.6],
                        [87.2, 20.6],
                        [89.2, 14.6],
                        [93.2, 18.6],
                        [98, 20.8]
                    ]
                }, {
                    type : 4,
                    gal : 4,
                    sn : 11,
                    ov : "bgs-i_overlay_lrc5_zalexe_loop.png",
                    pos : [
                        [97.2, 19],
                        [98, 20.8],
                        [101.6, 18.8]
                    ]
                }, {
                    type : 4,
                    gal : 4,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc5_extrinsic_reach.png",
                    pos : [
                        [80.8, 43.6],
                        [85.3, 42.8],
                        [82, 47],
                        [81.6, 50.8],
                        [84.4, 49.8],
                        [89.6, 46.2],
                        [92.8, 43.8],
                        [98.8, 41.4],
                        [100, 40.2]
                    ]
                }, {
                    type : 4,
                    gal : 4,
                    sn : 12,
                    ov : "bgs-i_overlay_lrc5_greater_wheel.png",
                    pos : [
                        [62.4, 12.6],
                        [64, 17.6],
                        [67.2, 23.8],
                        [70, 22.8],
                        [74.8, 26.4],
                        [80.8, 24.4],
                        [85.6, 21.8],
                        [88.4, 25.6]
                    ]
                }, {
                    type : 4,
                    gal : 4,
                    sn : 12,
                    ov : "bgs-i_overlay_lrc5_greater_wheel.png",
                    pos : [
                        [67.2, 23.8],
                        [69.2, 17.6],
                        [71.6, 12.4],
                        [76.4, 9.8],
                        [76, 4.4],
                        [70.8, 5.2],
                        [64.8, 6.2],
                        [64, 12.8],
                        [62.4, 12.8]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc6_centreward_span.png",
                    pos : [
                        [2.8, 34.6],
                        [2.8, 37.2],
                        [4.4, 31.6],
                        [5.2, 34],
                        [11.2, 34.8],
                        [15.6, 33.6],
                        [16.82, 39.9],
                        [14.4, 40],
                        [18.83, 43],
                        [18.4, 49.6]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 13,
                    ov : "bgs-i_overlay_lrc6_lane_1.png",
                    pos : [
                        [61.6, 39.8],
                        [62.8, 41.8],
                        [68.4, 43],
                        [69.2, 40.6],
                        [71.6, 39.6],
                        [72.4, 33.6]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 13,
                    ov : "bgs-i_overlay_lrc6_lane_1.png",
                    pos : [
                        [72.4, 33.6],
                        [65.6, 33.4],
                        [60, 32],
                        [53.6, 33.2]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 13,
                    ov : "bgs-i_overlay_lrc6_lane_1.png",
                    pos : [
                        [53.6, 33.2],
                        [53.2, 27.6],
                        [52, 23.4],
                        [46, 21],
                        [41.2, 17.4],
                        [38, 14.4],
                        [35.2, 8.8],
                        [34.8, 6.6]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 13,
                    ov : "bgs-i_overlay_lrc6_lane_1.png",
                    pos : [
                        [34.8, 6.6],
                        [40.4, 2.4],
                        [46.8, 3.6],
                        [52.4, 4.6],
                        [57.2, 6.6]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 14,
                    ov : "bgs-i_overlay_lrc6_lane_2.png",
                    pos : [
                        [22.4, 49.6],
                        [26, 48.8],
                        [27.6, 48.6],
                        [33.2, 44.6],
                        [37.6, 41.6]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 14,
                    ov : "bgs-i_overlay_lrc6_lane_2.png",
                    pos : [
                        [37.6, 41.6],
                        [41.2, 46.2],
                        [42.4, 44.8],
                        [43.2, 44.4]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 14,
                    ov : "bgs-i_overlay_lrc6_lane_2.png",
                    pos : [
                        [43.2, 44.4],
                        [38.8, 40],
                        [34.4, 35],
                        [28.8, 31],
                        [28.8, 28.4],
                        [29.6, 27.2],
                        [33.6, 26.8]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 14,
                    ov : "bgs-i_overlay_lrc6_lane_2.png",
                    pos : [
                        [33.6, 26.8],
                        [29.6, 24.4],
                        [29.6, 23.6],
                        [24.4, 21.4]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 14,
                    ov : "bgs-i_overlay_lrc6_lane_2.png",
                    pos : [
                        [24.4, 21.4],
                        [30.4, 19],
                        [25.6, 15],
                        [25.2, 14.8],
                        [28, 9],
                        [32.8, 5.4],
                        [37.6, 5.8]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 15,
                    ov : "bgs-i_overlay_lrc6_remlock_road.png",
                    pos : [
                        [97.2, 40.4],
                        [101.2, 37.8]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 15,
                    ov : "bgs-i_overlay_lrc6_remlock_road.png",
                    pos : [
                        [101.2, 37.8],
                        [95.6, 35.6],
                        [95.2, 29.8],
                        [95.2, 22.8],
                        [100, 20.8]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 15,
                    ov : "bgs-i_overlay_lrc6_remlock_road.png",
                    pos : [
                        [95.6, 35.6],
                        [96.4, 35],
                        [97.2, 31.8],
                        [98.8, 25.4]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 15,
                    ov : "bgs-i_overlay_lrc6_remlock_road.png",
                    pos : [
                        [97.2, 31.8],
                        [101.2, 32]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 16,
                    ov : "bgs-i_overlay_lrc6_rimward_arc.png",
                    pos : [
                        [65.6, 33.4],
                        [69.6, 30.6]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 16,
                    ov : "bgs-i_overlay_lrc6_rimward_arc.png",
                    pos : [
                        [69.6, 30.6],
                        [68, 27],
                        [66.4, 25.6]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 16,
                    ov : "bgs-i_overlay_lrc6_rimward_arc.png",
                    pos : [
                        [66.4, 25.6],
                        [69.6, 19.8],
                        [73.2, 14.8],
                        [79.2, 12.2],
                        [82.8, 8.2]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 16,
                    ov : "bgs-i_overlay_lrc6_rimward_arc.png",
                    pos : [
                        [82.8, 8.2],
                        [86.4, 12],
                        [92.8]
                    ]
                }, {
                    type : 4,
                    gal : 5,
                    sn : 16,
                    ov : "bgs-i_overlay_lrc6_rimward_arc.png",
                    pos : [
                        [92.8],
                        [93.2, 8],
                        [97.6, 6.2],
                        [99.6, 5.2]
                    ]
                }, {
                    type : 4,
                    gal : 6,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc7_lane_1.png",
                    pos : [
                        [60.4, 32],
                        [66.8, 35],
                        [73.2, 35.4],
                        [74, 33.2],
                        [79.2, 28.8],
                        [81.2, 34.4],
                        [81.6, 35.6],
                        [86.8, 34.8],
                        [90, 30.4],
                        [90.8, 28.4],
                        [94.4, 27.6],
                        [92.8, 25.4],
                        [86.8, 22.4],
                        [88.8, 20.6],
                        [82.4, 19.6]
                    ]
                }, {
                    type : 4,
                    gal : 6,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc7_the_road.png",
                    pos : [
                        [8.4, 24.8],
                        [11.6, 25],
                        [14.4, 18.8],
                        [14.4, 11.8],
                        [16.8, 11.2],
                        [22.8, 8.6],
                        [26, 8],
                        [28, 6.4],
                        [32, 8.2],
                        [34.4, 13.2],
                        [39.6, 17.2],
                        [42.4, 19],
                        [48, 15.8],
                        [50.4, 16.6],
                        [52, 17],
                        [56.8, 13.4],
                        [57.2, 12.8]
                    ]
                }, {
                    type : 4,
                    gal : 6,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc7_far_rift_reach.png",
                    pos : [
                        [0.4, 40.4],
                        [5.6, 41.2],
                        [11.6, 43.4],
                        [13.2, 45.6],
                        [13.6, 43.8],
                        [19.2, 43],
                        [18, 42.2],
                        [15.6, 36.2]
                    ]
                }, {
                    type : 4,
                    gal : 6,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc7_isisian_detour.png",
                    pos : [
                        [14.4, 11.8],
                        [8.4, 10.8],
                        [4.8, 14.6],
                        [4.8, 15.8],
                        [3.6, 15.2],
                        [3.2, 14.4],
                        [2, 13.6],
                        [5.6, 11.2],
                        [6.4, 9.2]
                    ]
                }, {
                    type : 4,
                    gal : 6,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc7_quandixe_connection.png",
                    pos : [
                        [21.2, 27.8],
                        [25.2, 30.6],
                        [24.4, 33.2],
                        [29.6, 35.2],
                        [34.8, 40],
                        [41.2, 41.2],
                        [46, 43]
                    ]
                }, {
                    type : 4,
                    gal : 7,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc8_centreward_flight_refugee_trail.png",
                    pos : [
                        [34.8, 46.2],
                        [38, 43.6],
                        [40.4, 47.8],
                        [44.4, 49],
                        [46.8, 49.6],
                        [51.6, 47.8]
                    ]
                }, {
                    type : 4,
                    gal : 7,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc8_hitachi_trade_annex.png",
                    pos : [
                        [49.2, 42.6],
                        [52, 40.8],
                        [53.2, 40.2],
                        [58.8, 39.2],
                        [63.6, 38.8]
                    ]
                }, {
                    type : 4,
                    gal : 7,
                    sn : 1,
                    ov : "bgs-i_overlay_lrc8_rimward_decamp_refugee_trail.png",
                    pos : [
                        [53.2, 40.2],
                        [58.8, 39.2],
                        [63.6, 38.8]
                    ]
                }, {
                    type : 4,
                    gal : 7,
                    sn : 20,
                    ov : "bgs-i_overlay_lrc8_nemorican_arc.png",
                    pos : [
                        [74, 37.4],
                        [76.4, 43.6],
                        [81.6, 46],
                        [85.2, 44.8],
                        [92, 44.2],
                        [95.2, 41.6],
                        [90.8, 39.8],
                        [89.6, 35.6],
                        [83.2, 33.2],
                        [86.4, 27.6],
                        [88, 26.4],
                        [90.4, 25.2],
                        [88.8, 21],
                        [95.6, 20.4],
                        [96.4, 14.4],
                        [97.6, 7.8],
                        [94.4, 5.4]
                    ]
                }, {
                    type : 4,
                    gal : 7,
                    sn : 20,
                    ov : "bgs-i_overlay_lrc8_nemorican_arc.png",
                    pos : [
                        [50, 2],
                        [51.6, 2],
                        [54.4, 2.6],
                        [58.8, 8.4],
                        [64, 8.8],
                        [65.6, 8],
                        [68.8, 12],
                        [73.6, 12.6],
                        [77.2, 14.4],
                        [76, 20],
                        [81.6, 22.2],
                        [87.2, 17.6],
                        [85.6, 12.4],
                        [91.6, 15],
                        [90, 9.2],
                        [94.4, 5.4]
                    ]
                }, {
                    type : 4,
                    gal : 7,
                    sn : 20,
                    ov : "bgs-i_overlay_lrc8_nemorican_arc.png",
                    pos : [
                        [32.4, 25.8],
                        [34.4, 28.6],
                        [41.2, 27.6],
                        [46.4, 23.2],
                        [43.2, 18.2],
                        [46.4, 17.4],
                        [48.4, 13.4],
                        [49.2, 12.4],
                        [48.4, 6.6],
                        [49.2, 4],
                        [50, 2]
                    ]
                }, {
                    type : 4,
                    gal : 7,
                    sn : 20,
                    ov : "bgs-i_overlay_lrc8_nemorican_arc.png",
                    pos : [
                        [0.4, 3.4],
                        [0.8, 9.2],
                        [4.8, 11.2],
                        [8.4, 15.8],
                        [5.6, 20.8],
                        [6.4, 25.2],
                        [3.6, 31],
                        [8.8, 33],
                        [10.4, 38.4],
                        [14.4, 37.8],
                        [11.6, 42.2],
                        [17.6, 44.4],
                        [15.2, 49.8],
                        [20.4, 50.8]
                    ]
                }, {
                    type : 4,
                    gal : 7,
                    sn : 20,
                    ov : "bgs-i_overlay_lrc8_nemorican_arc.png",
                    pos : [
                        [0.4, 3.4],
                        [5.6, 2.6],
                        [6.8, 2.8],
                        [11.2, 1.2],
                        [12, 6.8],
                        [10.4, 13.6],
                        [15.6, 14.6],
                        [21.6, 13.4],
                        [23.6, 16],
                        [26.8, 19],
                        [31.6, 21.4],
                        [34.8, 23.8],
                        [37.6, 19.2]
                    ]
                }, {
                    type : 4,
                    gal : 7,
                    sn : 20,
                    ov : "bgs-i_overlay_lrc8_nemorican_arc.png",
                    pos : [
                        [37.6, 19.2],
                        [42.4, 22.2],
                        [47.6, 25.8],
                        [48.8, 26.8],
                        [48.8, 25.6],
                        [51.2, 24.6],
                        [56, 24],
                        [60.8, 28.2],
                        [60.8, 33.2],
                        [63.6, 38.8],
                        [68.4, 39.6]
                    ]
                }
            ],
            specials : [{
                    gal : 0,
                    ov : "bgs-i_overlay_lrc1_navy_hq.png",
                    txt : "Navy HQs",
                    check : "GalNavy"
                }, {
                    gal : 1,
                    ov : "bgs-i_overlay_lrc2_navy_hq.png",
                    txt : "Navy HQs",
                    check : "GalNavy"
                }, {
                    gal : 2,
                    ov : "bgs-i_overlay_lrc3_navy_hq.png",
                    txt : "Navy HQs",
                    check : "GalNavy"
                }, {
                    gal : 3,
                    ov : "bgs-i_overlay_lrc4_navy_hq.png",
                    txt : "Navy HQs",
                    check : "GalNavy"
                }, {
                    gal : 4,
                    ov : "bgs-i_overlay_lrc5_navy_hq.png",
                    txt : "Navy HQs",
                    check : "GalNavy"
                }, {
                    gal : 5,
                    ov : "bgs-i_overlay_lrc6_navy_hq.png",
                    txt : "Navy HQs",
                    check : "GalNavy"
                }, {
                    gal : 6,
                    ov : "bgs-i_overlay_lrc7_navy_hq.png",
                    txt : "Navy HQs",
                    check : "GalNavy"
                }, {
                    gal : 7,
                    ov : "bgs-i_overlay_lrc8_navy_hq.png",
                    txt : "Navy HQs",
                    check : "GalNavy"
                }
            ]
        };
        this.mapMax = [
            [8, 5, 1],
            [11, 7, 1],
            [8, 8, 1],
            [12, 11, 1],
            [6, 12, 1],
            [15, 19, 1],
            [6, 5, 1],
            [11, 9, 1]
        ]; // # max regions,routes,specials
        this.ini = 1;
        this.block = clock.days + this.helper.randSpan(this.minInter, this.maxInter);

        if (this.logging) {
            this.block = 1;
        }

        if (missionVariables.bgs_mapStats) {
            this.mapStats = JSON.parse(missionVariables.bgs_mapStats);
            this.mapStats.forEach(this.changeToN, this);
            missionVariables.bgs_mapStats = null;
        } else {
            /*
            this.mapStats = [
            [0xff,0x1f,0x1],
            [0x7ff,0x7f,0x1],
            [0xff,0xff,0x1],
            [0xfff,0x7ff,0x1],
            [0x3f,0xfff,0x1],
            [0x7fff,0x7ffff,0x1],
            [0x3f,0x1f,0x1],
            [0x7ff,0x1ff,0x1]
            ]; // full set - bitmask
             */
            this.mapStats = [
                [0x1, 0x3, 0x1],
                [0x1, 0x1, 0x1],
                [0x1, 0x1, 0x1],
                [0xf, 0x3, 0x1],
                [0x1, 0x3, 0x1],
                [0x1, 0x1, 0x1],
                [0x1, 0x1, 0x1],
                [0x1, 0x1, 0x1]
            ]; // basic set - bitmask
        }

        this.jobDone = [0, 0, 0, 0, 0, 0, 0, 0];
    };

    /**
     * Called when the player’s alert status (player.alertCondition) changes.
     * Only the player and stations have an alert condition. (world script and station scripts)
     *
     * Called when the guiScreen changes.
     *
     * Note that the screen can have changed again in the meantime by the action of other oxps.
     * Therefore, it will generally better to test for the global guiScreen to see which page is really on display
     * instead of using the "to" parameter. (world script only)
     *
     * This handler will not fire for every screen the player can switch to, but only when switching to any of the
     * following screens:
     *
     * GUI_SCREEN_MAIN, GUI_SCREEN_STATUS, GUI_SCREEN_MANIFEST, GUI_SCREEN_SYSTEM_DATA, GUI_SCREEN_OPTIONS,
     * GUI_SCREEN_EQUIP_SHIP, GUI_SCREEN_SHIPYARD, GUI_SCREEN_SHORT_RANGE_CHART, GUI_SCREEN_LONG_RANGE_CHART,
     * GUI_SCREEN_MARKET, GUI_SCREEN_REPORT, GUI_SCREEN_INTERFACES
     *
     * Called if there are no mission / report screens active, and the player is docked to a station.
     * It gets fired at game startup, upon docking, and after a docking report or previous mission screen has ended.
     * (world script only)
     */
    this.alertConditionChanged = this.guiScreenChanged = this.missionScreenOpportunity = function () {
        if (this.ini) {
            this.doIni();
            this.checkDone();
        }

        delete this.alertConditionChanged;
        delete this.guiScreenChanged;
        delete this.missionScreenOpportunity;
    };

    /**
     * Called whenever the player saves a game.
     */
    this.playerWillSaveGame = function () {
        missionVariables.bgs_mapStats = JSON.stringify(this.mapStats);

        this.guiScreenChanged = function () {
            missionVariables.bgs_mapStats = null;
            delete this.guiScreenChanged;
        };
    };

    /**
     * Called at the end of the docking tunnel effect.
     */
    this.shipDockedWithStation = function () {
        if (this.ini || this.block > clock.days) {
            return;
        }

        if (system.isInterstellarSpace || system.sun.isGoingNova || system.sun.hasGoneNova) {
            return;
        }

        var q = Math.floor(Math.random() * 3),
        c = this.checkMissing(q),
        en;

        if (c) {
            en = this.getSpecific(q, c - 1, galaxyNumber);

            if (en.hasOwnProperty("sn")) {
                this.buildSnoopersMessage(en, c);
            } else if (en.hasOwnProperty("direct")) {
                switch (q) {
                case 0:
                    worldScripts["BGS-M"].addToLRC(en);
                    break;
                case 1:
                    worldScripts["BGS-M"].addToLRC(en);
                    break;
                case 2:
                    worldScripts["BGS-M"].addToLRCSpecial(en);
                    break;
                }

                this.mapStats[galaxyNumber][q] |= Math.pow(2, c - 1);
            }
        }

        return;
    };

    /**
     * Called at the end of the launch tunnel effect.
     */
    this.shipLaunchedFromStation = function () {
        if (this.logging) {
            log(this.name,
                "Current galaxy bitmask: " + this.mapStats[galaxyNumber] + " Next date: " + (this.block + 1));
        }
    };

    /* Other global functions. */

    /**
     * @param desc
     */
    this.killSelf = function (desc) {
        var prop;

        if (desc !== null) {
            player.consoleMessage(this.name + " - Check your Latest.log.", 10);
            log(this.name, this.name + " - Shutting down." + desc);
        }

        for (prop in this) {
            if (this.hasOwnProperty(prop)) {
                if (prop !== 'name' && prop !== 'version') {
                    delete this[prop];
                }
            }
        }

        this.deactivated = true;

        return;
    };

    /**
     * @param element
     */
    this.changeToN = function (element) {
        element[0] = parseInt(element[0], null);
        element[1] = parseInt(element[1], null);
        element[2] = parseInt(element[2], null);
    };

    /**
     * Insert basic set
     */
    this.doIni = function () {
        var cl = 0,
        cp = 0,
        i;

        for (i = 0; i < this.xmaps.areas.length; i += 1) {
            if (this.xmaps.areas[i].gal !== cl) {
                cl += 1;
                cp += this.mapMax[this.xmaps.areas[i - 1].gal][0];
            }

            if ((this.mapStats[this.xmaps.areas[i].gal][0] & Math.pow(2, i - cp))) {
                worldScripts["BGS-M"].addToLRC(this.xmaps.areas[i]);
            }
        }

        cl = 0;
        cp = 0;

        for (i = 0; i < this.xmaps.lanes.length; i += 1) {
            if (this.xmaps.lanes[i].gal !== cl) {
                cl += 1;
                cp += this.mapMax[this.xmaps.lanes[i - 1].gal][1];
            }

            if ((this.mapStats[this.xmaps.lanes[i].gal][1] & Math.pow(2, i - cp))) {
                worldScripts["BGS-M"].addToLRC(this.xmaps.lanes[i]);
            }
        }

        cl = 0;
        cp = 0;

        for (i = 0; i < this.xmaps.specials.length; i += 1) {
            if (this.xmaps.specials[i].gal !== cl) {
                cl += 1;
                cp += this.mapMax[this.xmaps.specials[i - 1].gal][2];
            }

            if ((this.mapStats[this.xmaps.specials[i].gal][2] & Math.pow(2, i - cp))) {
                // Check requirement
                if (this.xmaps.specials[i].hasOwnProperty("check") && !worldScripts[this.xmaps.specials[i].check]) {
                    continue;
                }

                worldScripts["BGS-M"].addToLRCSpecial(this.xmaps.specials[i]);
            }
        }

        delete this.ini;
        delete this.doIni;

        return;
    };

    /**
     * Check current galaxy
     */
    this.checkMissing = function (what) {
        var max = Math.pow(2, this.mapMax[galaxyNumber][what]) - 1,
        cur = this.mapStats[galaxyNumber][what],
        r = this.helper.baseChange(max - cur, 2),
        i;

        for (i = r.length; i >= 0; i -= 1) {
            if (r[i] === "1") {
                return (r.length - i);
            }
        }

        return 0;
    };

    /**
     * Get entry
     */
    this.getSpecific = function (t, w, g) {
        var r,
        c = 0,
        i;

        switch (t) {
        case 0:
            r = "areas";
            break;
        case 1:
            r = "lanes";
            break;
        case 2:
            r = "specials";
            break;
        }

        for (i = 0; i < this.xmaps[r].length; i += 1) {
            if (this.xmaps[r][i].gal !== g) {
                continue;
            }

            if (w === c) {
                return (this.xmaps[r][i]);
            }

            c += 1;
        }

        return 0;
    };

    /**
     * Sum xy
     */
    this.getCPX = function (element) {
        this.p.x += element;
    };

    this.getCPY = function (element) {
        this.p.y += element;
    };

    this.getCPL = function (element) {
        this.p.y += element[1];
        this.p.x += element[0];
    };

    /**
     * Prepare Snoopers message
     */
    this.buildSnoopersMessage = function (obj, c) {
        var a = ["One", "Two", "Three", "Four", "Five", "Six", "Seven", "Eight"],
        m = "Map-Update #" + (obj.gal + 1),
        snc;

        this.p = new Vector3D([0, 0, 0]);

        switch (obj.type) {
        case 1:
            m += this.helper.strLZZ(c) + "0000";
            this.p.x = obj.posx;
            this.p.y = obj.posy;
            break;
        case 2:
            m += this.helper.strLZZ(c) + "0000";
            this.p.x = obj.posx;
            this.p.y = obj.posy;
            break;
        case 3:
            m += this.helper.strLZZ(c) + "0000";
            obj.ax.forEach(this.getCPX, this);
            this.p.x /= obj.ax.length;
            obj.ay.forEach(this.getCPY, this);
            this.p.y /= obj.ay.length;
            break;
        case 4:
            m += "0000" + this.helper.strLZZ(c);
            obj.pos.forEach(this.getCPL, this);
            this.p.x /= obj.pos.length;
            this.p.y /= obj.pos.length;
            break;
        }

        m += ": The Galactic Co-operative of Worlds has just officially christened a new " +
        (obj.type > 3 ? "space lane" : "area");
        m += " in Sector " + a[obj.gal] + " and Nav-Computers are receiving a immediate update" +
        " via Hyperspeed Secure Comms on all GALCOP stations.\n\n";
        m += "The '" + obj.ov.toUpperCase().slice(19, obj.ov.length - 4).replace(/_/g, " ");

        if (obj.sn === 1) {
            m += "'s center is located " + this.p.distanceTo([51.2, 25.6, 0]).toFixed(2) + " LYs to the " +
            this.helper.mapCoordsDirection(this.p, [51.2, 25.6, 0]) + " of the Sectors center.";
        } else {
            m += "is one of the main " + (obj.type > 3 ? "space lane" : "area") + "s in Sector " + a[obj.gal] +
            " under control of the Galactic Co-operative of Worlds.";
        }

        m += " Commanders are advised to upgrade their ships systems to take advantage of these features.";

        if (this.$snoopersInstalled) {
            snc = worldScripts.snoopers.insertNews({
                    ID : this.name,
                    Message : m,
                    Priority : 2,
                    Pic : "snoopers_gcnewsA14.png",
                    Model : "bgs-xload",
                    Pos : [4, 3, 14]
                });

            if (!snc) {
                this.block = clock.days + this.helper.randSpan(this.minInter, this.maxInter);
            }

            if (this.logging) {
                log(this.name, "Snoopers returned: " + snc);
            }
        } else {
            this.block = clock.days + this.helper.randSpan(this.minInter, this.maxInter);
            this.newsDisplayed(m.substr(0, 20));
        }

        return;
    };

    /**
     * Snoopers callback
     *
     * @param which
     *              first 20 characters of the passed message
     */
    this.newsDisplayed = function (which) {
        var a = which.slice(12),
        gal = parseInt(a[0], null) - 1,
        tp = parseFloat(a.slice(2)),
        t,
        w,
        ins,
        p = ["areas", "lanes", "specials"],
        cur,
        s = 0,
        cl = 0,
        i;

        if (gal !== galaxyNumber) {
            player.commsMessage("Map-Update failed!", 10);

            return;
        }

        if (tp > 9999) {
            t = 0;
            w = parseFloat(a.slice(2, 4)) - 1;
        } else if (tp > 99) {
            t = 2;
            w = parseFloat(a.slice(4, 6)) - 1;
        } else {
            t = 1;
            w = parseFloat(a.slice(6, 8)) - 1;
        }

        ins = this.getSpecific(t, w, gal);

        if (ins.hasOwnProperty("type")) {
            if (ins.sn !== 1) {
                for (i = 0; i < this.xmaps[p[t]].length; i += 1) {
                    cur = this.xmaps[p[t]][i];

                    if (cur.gal !== galaxyNumber) {
                        cl += 1;
                    }

                    if (cur.sn === ins.sn) {
                        worldScripts["BGS-M"].addToLRC(cur);
                        s += Math.pow(2, i - cl);
                    }
                }

                this.mapStats[galaxyNumber][t] |= s;
            } else {
                worldScripts["BGS-M"].addToLRC(ins);
                this.mapStats[galaxyNumber][t] |= Math.pow(2, w);
            }

            this.block = clock.days + this.helper.randSpan(this.minInter, this.maxInter);

            if (this.logging) {
                this.block = 1;
            }

            this.checkDone();
        }

        return;
    };

    /**
     *
     */
    this.checkDone = function () {
        var a = 0,
        j;

        for (j = 0; j < 8; j += 1) {
            if (this.mapStats[j][0] === Math.pow(2, this.mapMax[j][0]) - 1) {
                this.jobDone[j] |= Math.pow(2, 0);
            }

            if (this.mapStats[j][1] === Math.pow(2, this.mapMax[j][1]) - 1) {
                this.jobDone[j] |= Math.pow(2, 1);
            }

            if (this.mapStats[j][2] === Math.pow(2, this.mapMax[j][2]) - 1) {
                this.jobDone[j] |= Math.pow(2, 2);
            }

            a += this.jobDone[j];
        }

        if (this.logging) {
            log(this.name, "a:" + a + " " + this.jobDone);
        }

        if (a === 56) {
            this.killSelf(null); //silent kill, job is completely done
        }

        return;
    };
}.bind(this)());
